[![Docs](https://readthedocs.org/projects/ai2-climate-emulator/badge/?version=latest)](https://ai2-climate-emulator.readthedocs.io/en/latest/)

# FME: Weather/Climate Model Emulation
This package contains code to train and evaluate weather/climate model emulators as seen in
"ACE: A fast, skillful learned global atmospheric model for climate prediction" ([arxiv:2310.02074](https://arxiv.org/abs/2310.02074))
and "Application of the Ai2 Climate Emulator to E3SMv2's global atmosphere model, with a focus on precipitation fidelity"
([JGR-ML](https://agupubs.onlinelibrary.wiley.com/doi/full/10.1029/2024JH000136)).


## Installation

The package can be installed via PyPI using:

```
pip install fme
```

## Quickstart

A quickstart guide may be found [here](https://ai2-climate-emulator.readthedocs.io/en/latest/quickstart.html).

## Documentation

See complete documentation [here](https://ai2-climate-emulator.readthedocs.io/en/latest/).
